@@ -1,28 +1,29 @@
 import re
 
 from botocore.exceptions import ClientError
-from figcli.config.commands import share
+from figgy.data.dao.config import ConfigDao
+from figgy.data.dao.replication import ReplicationDao
+from figgy.models.replication_config import ReplicationType, ReplicationConfig
 from prompt_toolkit import prompt
 
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.types.config import ConfigCommand
-from figcli.config.constants import *
+from figcli.config.commands import share
+from figcli.config.style.style import FIGGY_STYLE
 from figcli.io.output import Output
-from figgy.models.replication_config import ReplicationType, ReplicationConfig
 from figcli.svcs.observability.anonymous_usage_tracker import AnonymousUsageTracker
 from figcli.svcs.observability.version_tracker import VersionTracker
 from figcli.utils.utils import Utils
-from figcli.config.style.style import FIGGY_STYLE
 
 
 class Share(ConfigCommand):
 
-    def __init__(self, ssm_init, config_init, config_completer_init, colors_enabled: bool,
-                 config_context: ConfigContext):
+    def __init__(self, ssm_init, repl_init: ReplicationDao,
+                 config_completer_init, colors_enabled: bool, config_context: ConfigContext):
         super().__init__(share, colors_enabled, config_context)
 
         self._ssm = ssm_init
-        self._config = config_init
+        self._repl = repl_init
         self._config_completer = config_completer_init
         self._utils = Utils(colors_enabled)
         self._out = Output(colors_enabled)
@@ -69,13 +70,13 @@ class Share(ConfigCommand):
                                      "proper permissions to share the provided Name.")
 
             namespace = self._utils.parse_namespace(dest)
-
-            repl_config = ReplicationConfig(dest, self.run_env,
-                                            namespace, key, ReplicationType(REPL_TYPE_APP))
-            self._config.put_config_repl(repl_config)
+            print(f'RUN_ENV: {self.run_env}   ')
+            repl_config = ReplicationConfig(destination=dest, env_alias=self.run_env.env,
+                                            namespace=namespace, source=key, type=ReplicationType.APP.value)
+            self._repl.put_config_repl(repl_config)
             self._out.success(f"[[{key}]] successfully shared.")
-            to_continue = input(f"Share another? (Y/n): ")
-            to_continue = to_continue if to_continue != '' else 'y'
+            to_continue = input(f"Share another? (y/N): ")
+            to_continue = to_continue if to_continue != '' else 'n'
             share_another = to_continue.lower() == "y"
 
     @VersionTracker.notify_user
