@@ -4,10 +4,12 @@ from figcli.config.style.palette import Palette
 
 
 class Color:
-    def __init__(self, colors_enabled: bool, palette=Palette()):
+    def __init__(self, colors_enabled: bool, palette=None):
         self.bl, self.gr, self.rd, self.fg_bl, self.fg_gr, self.fg_rd, self.rs = '', '', '', '', '', '', ''
         self.yl, self.fg_yl, self.bl_val, self.gr_val, self.yl_val, self.rd_val = '', '', '', '', '', ''
+
         if colors_enabled:
+            palette = palette if palette else Palette()
             self.bl = 'blue'
             self.rd = 'red'
             self.yl = 'yellow'
